pub struct RegexFlags {
pub case_insensitive: bool,
pub multi_line: bool,
pub dot_matches_new_line: bool,
}Expand description
Optional flags that can be applied when constructing a regex.
Fields
case_insensitive: boolmulti_line: booldot_matches_new_line: boolTrait Implementations
Sourceimpl Clone for RegexFlags
impl Clone for RegexFlags
Sourcefn clone(&self) -> RegexFlags
fn clone(&self) -> RegexFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegexFlags
impl Debug for RegexFlags
Sourceimpl Default for RegexFlags
impl Default for RegexFlags
Sourcefn default() -> RegexFlags
fn default() -> RegexFlags
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for RegexFlags
impl PartialEq for RegexFlags
Sourcefn eq(&self, other: &RegexFlags) -> bool
fn eq(&self, other: &RegexFlags) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RegexFlags
impl Eq for RegexFlags
impl StructuralPartialEq for RegexFlags