Skip to main contentModule prelude
Source - GlobPattern
- MatchSpan
- A half-open span within a UTF-8 string.
- NamedMatch
- A matched string value paired with an optional name and span.
- RegexCapture
- A captured value and its byte span.
- RegexFlags
- Optional flags that can be applied when constructing a regex.
- RegexPattern
- A reusable owned regex pattern wrapper.
- TextMatch
- A matched string value paired with its span.
- WildcardPattern
- A simple wildcard pattern with optional case-sensitivity metadata.
- MatchKind
- A conservative classification for how a match was found.
- glob_matches
- Returns
true when the glob pattern matches the full input string. - glob_to_regex
- Converts a glob pattern into an anchored regex string.
- has_regex_match
- Returns
true when the pattern matches any part of the input. - is_glob_pattern
- Returns
true when the input contains any unescaped glob syntax. - slice_match
- Returns a borrowed slice for a valid span.
- wildcard_matches
- Returns
true when the pattern matches the entire input.